{% if versiondata.name %}
{% set version_title = "v" + versiondata.version + " (" + versiondata.date + ")" %}
{% else %}
{% set version_title = versiondata.version + " (" + versiondata.date + ")" %}
{% endif %}
{{ top_underline * (version_title|length + 2) }}
 {{ version_title }}
{{ top_underline * (version_title|length + 2) }}

{% for section, _ in sections.items() %}
{% if sections[section] %}
{% for category, val in definitions.items() if category in sections[section]%}
{{ definitions[category]['name'] }} - {{ versiondata.version }}
{{ underlines[0] * ((definitions[category]['name']  + versiondata.version)|length + 3) }}

{% if definitions[category]['showcontent'] %}
{% for text, values in sections[section][category].items() %}
- {{ text }} ({{ values|join(', ') }})
{% endfor %}

{% else %}
- {{ sections[section][category]['']|join(', ') }}

{% endif %}
{% if sections[section][category]|length == 0 %}
No significant changes.

{% else %}
{% endif %}
{% endfor %}
{% else %}
No significant changes.


{% endif %}
{% endfor %}
